Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(385)

Unified Diff: remoting/host/desktop_session_proxy.h

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/desktop_session_agent.cc ('k') | remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_session_proxy.h
diff --git a/remoting/host/desktop_session_proxy.h b/remoting/host/desktop_session_proxy.h
index e1432289c997c9e7bd2e48883c7adbecffbff6ae..941b4e5e0138c910b5ad053b0de757669e203856 100644
--- a/remoting/host/desktop_session_proxy.h
+++ b/remoting/host/desktop_session_proxy.h
@@ -36,7 +36,6 @@ class MouseCursor;
} // namespace webrtc
struct SerializedDesktopFrame;
-struct SerializedMouseCursor;
namespace remoting {
@@ -82,7 +81,7 @@ class DesktopSessionProxy
scoped_ptr<AudioCapturer> CreateAudioCapturer();
scoped_ptr<InputInjector> CreateInputInjector();
scoped_ptr<ScreenControls> CreateScreenControls();
- scoped_ptr<webrtc::ScreenCapturer> CreateVideoCapturer();
+ scoped_ptr<webrtc::DesktopCapturer> CreateVideoCapturer();
scoped_ptr<webrtc::MouseCursorMonitor> CreateMouseCursorMonitor();
std::string GetCapabilities() const;
void SetCapabilities(const std::string& capabilities);
@@ -107,7 +106,7 @@ class DesktopSessionProxy
// on the |audio_capture_task_runner_| thread.
void SetAudioCapturer(const base::WeakPtr<IpcAudioCapturer>& audio_capturer);
// APIs used to implement the webrtc::ScreenCapturer interface. These must be
// called on the |video_capture_task_runner_| thread.
void CaptureFrame();
« no previous file with comments | « remoting/host/desktop_session_agent.cc ('k') | remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »
@@ -107,7 +106,7 @@ class DesktopSessionProxy
// on the |audio_capture_task_runner_| thread.
void SetAudioCapturer(const base::WeakPtr<IpcAudioCapturer>& audio_capturer);
- // APIs used to implement the webrtc::ScreenCapturer interface. These must be
+ // APIs used to implement the webrtc::DesktopCapturer interface. These must be
// called on the |video_capture_task_runner_| thread.
void CaptureFrame();

Powered by Google App Engine
This is Rietveld 408576698